timeintervaltools.resolve_overlaps_between_nonoverlapping_trees_excluding_remainders_less_than_rational
=======================================================================================================

.. autofunction:: abjad.tools.timeintervaltools.resolve_overlaps_between_nonoverlapping_trees_excluding_remainders_less_than_rational.resolve_overlaps_between_nonoverlapping_trees_excluding_remainders_less_than_rational
